%% set other metadata
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Actinopterygii'; 
metaData.order      = 'Clupeiformes'; 
metaData.family     = 'Engraulidae';
metaData.species    = 'Engraulis_encrasicolus'; 
metaData.species_en = 'Benguela anchovy'; 
metaData.T_typical  = C2K(15); % K, body temp
metaData.data_0     = {'ab'; 'aj'; 'ap'; 'am'; 'Lb'; 'Lj'; 'Lp'; 'Li'; 'Wdb'; 'Wdj'; 'Wwp'; 'Wwi'; 'Ri'};  % tags for different types of zero-variate data
metaData.data_1     = {'t-L'; 'T-ah'}; % tags for different types of uni-variate data

metaData.COMPLETE = 2.6; % using criteria of LikaKear2011

metaData.author   = {'Grea Groenewald'};        
metaData.date_subm = [2017 10 11];                           
metaData.email    = {'grea.groenewald@gmail.com'};                 
metaData.address  = {'UCT, Cape Town'};

% metaData.curator     = {'FirstName LastName'};
% metaData.email_cur   = {'myname@myuniv.univ'}; 
% metaData.date_acc    = [2015 04 22];

%% set data
% zero-variate data
Aab = 1.33;      units.ab = 'd';    label.ab = 'age at birth';           bibkey.ab = {'Kingetal1978','ArmThom1989'}; 
  temp.ab = C2K(20); units.temp.ab = 'K'; label.temp.ab = 'temperature';    
Aaj = 67;     units.aj = 'd';    label.aj = 'age at metam';           bibkey.aj = 'ArmThom1989'; 
  temp.aj = C2K(19); units.temp.aj = 'K'; label.temp.aj = 'temperature'; 
Aap = 1*365; units.ap = 'd';    label.ap = 'age at puberty';         bibkey.ap = 'LeCLus1979';
  temp.ap = C2K(15);  units.temp.ap = 'K'; label.temp.ap = 'temperature';
  comment.ap = '';
Aam = 4*365;  units.am = 'd';    label.am = 'life span';              bibkey.am = 'Barangeetal2009';   
  temp.am = C2K(13); units.temp.am = 'K'; label.temp.am = 'temperature';
  comment.am = 'average life span: 4 years in the Benguela';

ALb = 0.3;    units.Lb = 'cm';   label.Lb = 'standard length at birth';  bibkey.Lb = {'Kingetal1978','ArmThom1989'};
  comment.Lb = ' ';  
ALj = 3.5;   units.Lj = 'cm';   label.Lj = 'standard length at metam';bibkey.Lj = 'ArmThom1989';
  comment.Lj = 'Total length at Metamorphosis is 3.0-3.5cm which is 2.59cm standard length';
ALp = 8;      units.Lp = 'cm';   label.Lp = 'standard length at puberty';bibkey.Lp = 'LeCLus1979';
    comment.Lp = 'length at first maturity 8.0cm,50% maturity at 9.5cm and are 100% maturity at between 11 and 12cm';
ALi = 16;     units.Li = 'cm';   label.Li = 'ultimate total length';  bibkey.Li = 'Barangeetal2009';
  comment.Li = 'Average length for Age 4 individuals';

AWb = (0.00595 * ALb^3.186); units.Wb = 'g';    label.Wb = 'dry weight at birth';    bibkey.Wb = 'DAFF201216';
  comment.Wb = 'DAFF sample data from 2012-2016 from unplublished DAFF data';
AWj = (0.00595 * ALj^3.186);  units.Wj = 'g';    label.Wj = 'dry weight at metam';    bibkey.Wj = 'DAFF201216';
  comment.Wb = 'DAFF sample data from 2012-2016 from unplublished DAFF data';
AWp = (0.00595 * ALp^3.186); units.Wp = 'g';    label.Wp = 'wet weight at puberty';  bibkey.Wp = 'DAFF201216';
  comment.Wp = 'DAFF sample data from 2012-2016 from unplublished DAFF data';
AWi = (0.00595 * ALi^3.186); units.Wi = 'g';    label.Wi = 'ultimate wet weight';    bibkey.Wi = 'DAFF201216';
  comment.Wi = 'DAFF sample data from 2012-2016 from unplublished DAFF dataa';
  
ARF_batch = 530;   units.RFbatch = '#.eggs.g-1.spawn-1';  label.RFbatch = 'relative batch fecundity'; bibkey.Wi = 'vdLDur2013';
  comment.AFbatch = ['between 481 and 624 eggs g-1 female-1 Shelton et al. 1993;'];
ABatch = 20;  units.Batch = 'spawn.y-1'; label.Batch = 'number of batches of eggs spawned per year';  
AE_egg = 0.720; units.AE_egg = 'J.egg-1'; label.Ri = 'Energy content of 1g of egg'; bibkey.AE_gg = {'HunLeo1981','Sheletal1993'};
ARi = 1100;   units.Ri = '#/d';  label.Ri = 'maximum reprod rate';    bibkey.Ri = {'HunLeo1981','Sheletal1993'};   
  temp.Ri = C2K(15); units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
  comment.ARi = ['20 batches of eggs per year(Engraulis mordax Hunter & Leong 1981; between 481 and 624 eggs g-1 female-1 Shelton et al. 1993; ', ...
  'GSI  = 0.04 (PethRoos2013); Ri = 20 * 400 * 0.0041 * ALi ^3.2099 * 0.96 /365 = 922']; 
  
% uni-variate data
% embryo  
% King1978 formula: D = (43707.93*(T^ -2.41))/24 ; D developement time in
% days till hatching, T temperature (degC)
ATah = [ ... % temperature (C), developement time (days) till hatching
15	2.67;
16	2.28;
17	1.97;
18	1.72;
19	1.51;
20	1.33;
21	1.19;
22	1.06;
23	0.95;
24	0.86;
25	0.78;
26	0.71];
units.Tah = {'C', 'd'};  label.Tah = {'temperature', 'age at hatch'};  
bibkey.Tah = {'Kingetal1978'};

% adult growth at 13 C (on avarage)
% According to DAFF unpublished data 
% VBL equation: 
tLLsd = [ ... % t age in days, L total length (cm), Lsd standard deviation (cm)
1.5*365	12.70	1.54;
2.5*365	13.73	1.05;
3.5*365	13.95	1.48];
AtL = tLLsd(:,[1 2]); % remove third column
units.tL = {'d', 'cm'};     label.tL = {'time since birth', 'total length'};  bibkey.tL = {'Pecq2008'};
  temp.tL = C2K(13); units.temp.tL = 'K'; label.temp.tL = 'temperature';
 
                                
%% References
bibkey = 'ArmThom1989'; type = 'book,section'; bib = [ ...  
'author = {Armstrong,M.J.; Thomas,R.M.}, ' ...
'year = {1989}, ' ...
'section title  = {Clupeoids}, ' ...
'book title  = {Oceans of life off Southern Africa}, ' ...
'editors = {Payne,A.I.L. Crawford,R.J.M. }, ' ...
'publisher = {Vlaeberg Publishers, Cape Town}, ' ...
'pages = {105-122}, ' ];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Barangeetal2009'; type = 'book,section'; bib = [ ...  
'author = {Barange,M.A.; Bernal,M.; Cergole,M.C.; Cubillos,L.A.; Cunningham,C.L.; Daskalov,G.M.; De Oliveira,J.A.A.; Dickey-Collas,M.; Gaughan,D.J.; Hill,K.; Jacobson,L.D.; Koster,F.W.; Masse,J.; Niquen,M.; Nishida,H.; Oozeki,Y.; Palomera,I.; Saccardo,S.A.; Santojanni,A.; Serra,R.; Somarakis,S.; Stratoudakis,Y.; Uriarte,A.; van der Lingen,C.D.; Yatsu,A.}, ' ...
'year = {2009}, ' ...
'section title  = {Current trends in the assessment and management of stocks}, ' ...
'book title  = {Climate change and small pelagic fish}, ' ...
'editors = {Checkley,D. Roy,C. Alheit,J. Oozeki,Y. }, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {191-255}, ' ];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'DAFF201216'; type = 'unpublished data'; bib = [ ...  
'author = {Department of Agriculture, Forestry and Fisheries}, ' ...
'year = {2016}, ' ...
'title = {Survey data 2012-2016}, ' ...  
'journal = {Unpublished Data}, '];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'HunLeo1981'; type = 'Article'; bib = [ ...    
'author = {Hunter,J.R.; Leong,R.;}, ' ...
'year  = {1981}, ' ...
'title = {The spawning energetics of female northern anchovy, (\emph{Engraulis mordax})}, ' ...  
'journal = {Fisheries Bulletin}, ' ...
'volume = {79}, ' ...
'pages = {215--230}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kingetal1978'; type = 'Article'; bib = [ ...    
'author = {King,D.P.F.; Robertson,A.A.; Shelton,P.A.}, ' ...
'year  = {1978}, ' ...
'title = {Laboratory observations on the early development of the anchovy (\emph{Engraulis capensis}) from the Cape Peninsula.}, ' ...  
'journal = {Fisheries Bulletin}, ' ...
'volume = {10}, ' ...
'pages = {37--45}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'LeCLus1979'; type = 'Article'; bib = [ ...    
'author = {Le Clus,F.}, ' ...
'year  = {1979}, ' ...
'title = {Fecundity and maturity of anchovy (\emph{Engraulis capensis}) off South West Africa.}, ' ...  
'journal = {Fisheries Bulletin}, ' ...
'volume = {11}, ' ...
'pages = {26--38}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Pecq2008'; type = 'Phdthesis'; bib = [ ...    
'author = {Pecquerie, L.}, ' ...
'year  = {2008}, ' ...
'title = {Bioenergetic modelling of the growth, development and reproduction of a small pelagic fish: the {B}ay of {B}iscay anchovy}, ' ...  
'school = {VU University Amsterdam and Rennes University Agrocampus}, ' ...
'howpublished = {\url{http://www.bio.vu.nl/thb/research/bib/Pecq2008.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Sheletal1993'; type = 'Article'; bib = [ ...    
'author = {Shelton,P.A.; Armstrong,M.J.; Roel,B.A.}, ' ...
'year  = {1993}, ' ...
'title = {An Overview of the Application of the Daily Egg-Production Method in the Assessment and Management of Anchovy in the Southeast Atlantic}, ' ...  
'journal = {Fisheries Bulletin}, ' ...
'volume = {53}, ' ...
'pages = {778--794}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'vdLDur2013'; type = 'Article'; bib = [ ...    
'author = {van der Lingen, C. D.; Durholtz, M. D.}, ' ...
'year  = {2003}, ' ...
'title = {Review of variability in biomass, growth, and other characteristics of anchovy Engaulis encrasicolus and sardine Sardinops sagax in the Benguela current upwelling ecosystem}, ' ...  
'journal = {Unpublished Report}, '];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];

